package com.example.fitmarcetplacekuzminiv.Screens

import androidx.compose.foundation.layout.*
import androidx.compose.material3.*
import androidx.compose.runtime.*
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.input.PasswordVisualTransformation
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.compose.ui.text.font.FontWeight
import androidx.navigation.NavController
import com.example.fitmarcetplacekuzminiv.MainViewModel

// Авторизация
@Composable
fun AuthScreen(navController: NavController, mainViewModel: MainViewModel) {
    val email = remember { mutableStateOf("") }
    val password = remember { mutableStateOf("") }

    // Слушаем результат авторизации
    val authResult by mainViewModel.authResult

    // Если авторизация прошла успешно, переходим на main_screen
    LaunchedEffect(authResult) {
        if (authResult == "Success") {
            navController.navigate("main_screen") {
                popUpTo("auth_screen") { inclusive = true }
            }
        }
    }

    Box(
        modifier = Modifier
            .fillMaxSize(),
        contentAlignment = Alignment.Center
    ) {
        Column(
            horizontalAlignment = Alignment.CenterHorizontally,
            verticalArrangement = Arrangement.Center,
            modifier = Modifier
                .fillMaxWidth()
                .padding(16.dp)
        ) {
            // Добавляем заголовок "Авторизация"
            Text(
                text = "Авторизация",
                style = TextStyle(fontSize = 28.sp, fontWeight = FontWeight.Bold),
                color = Color.Black,
                modifier = Modifier.padding(bottom = 16.dp)
            )

            OutlinedTextField(
                value = email.value,
                onValueChange = { newText -> email.value = newText },
                label = { Text("Почта") },
                modifier = Modifier.fillMaxWidth()
            )
            Spacer(modifier = Modifier.height(16.dp))
            OutlinedTextField(
                value = password.value,
                onValueChange = { newText -> password.value = newText },
                label = { Text("Пароль") },
                visualTransformation = PasswordVisualTransformation(),
                modifier = Modifier.fillMaxWidth()
            )
            Spacer(modifier = Modifier.height(24.dp))
            Button(
                onClick = {
                    mainViewModel.onSignInEmailPassword(email.value, password.value)
                },
                colors = ButtonDefaults.buttonColors(
                    containerColor = Color(android.graphics.Color.parseColor("#32CD32")) // LimeGreen
                )
            ) {
                Text("Войти")
            }

            // Отображаем сообщение об ошибке, если авторизация не удалась
            if (authResult == "Error") {
                Spacer(modifier = Modifier.height(16.dp))
                Text(text = "Ошибка: неверный email или пароль", color = MaterialTheme.colorScheme.error)
            }
        }
    }
}
