package com.example.fitmarcetplacekuzminiv.Screens

import android.util.Log
import androidx.compose.foundation.Image
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.material3.CircularProgressIndicator
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.Text
import androidx.compose.material3.TopAppBar
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.getValue
import androidx.compose.runtime.internal.enableLiveLiterals
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.unit.dp
import coil.compose.AsyncImagePainter
import coil.compose.rememberAsyncImagePainter
import coil.request.ImageRequest
import coil.size.Size
import com.example.fitmarcetplacekuzminiv.Model.Products
import com.example.fitmarcetplacekuzminiv.R
import com.example.fitmarcetplacekuzminiv.domain.Constants
import io.github.jan.supabase.postgrest.from
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.withContext

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun MainScreen() {
    var products by remember { mutableStateOf<List<Products>>(listOf()) }

    var quantities = remember { mutableMapOf<Int , Int>() }

    Box(modifier = Modifier
        .fillMaxWidth()
        .padding(16.dp),
        contentAlignment = Alignment.TopStart) {
        Text(
            text = "WorkOut",
            modifier = Modifier)
        Image(painter = painterResource(id = R.drawable.piccart), contentDescription = "Cart",
            modifier = Modifier.size(24.dp)
        )
    }


    LaunchedEffect(Unit) {
        withContext(Dispatchers.IO) {
            products = Constants.supabase.from("products")
                .select()
                .decodeList<Products>()
            products.forEach { product ->
                Log.d("Products", product.name)
            }
        }
    }

    Spacer(modifier = Modifier.height(16.dp))

    LazyColumn {
        items(
            products,
            key = { product -> product.id },
        ) { product ->
            val imageState = rememberAsyncImagePainter(
                model = ImageRequest.Builder(LocalContext.current).data(product.imageurl)
                    .size(Size.ORIGINAL).build()
            ).state

            if (imageState is AsyncImagePainter.State.Error) {
                Box(
                    modifier = Modifier
                        .fillMaxWidth()
                        .height(200.dp),
                    contentAlignment = Alignment.Center
                ) {
                    CircularProgressIndicator()
                }
            }

            if (imageState is AsyncImagePainter.State.Success) {
                Image(
                    modifier = Modifier
                        .width(200.dp)
                        .height(200.dp),
                    painter = imageState.painter,
                    contentDescription = "",
                    contentScale = ContentScale.FillBounds
                )
            }

            Text(
                text = product.name,
                modifier = Modifier.padding(8.dp),
            )

            Text(
                text = "$${product.price}",
                modifier = Modifier.padding(start = 8.dp, bottom = 8.dp),
            )
            Box(
                modifier = Modifier
                    .padding(8.dp)
                    .fillMaxWidth(),
                contentAlignment = Alignment.Center
            ){
                Image(painter = painterResource(id = R.drawable.minus), contentDescription = "minus",
                    modifier = Modifier
                        .clickable{
                            if ((quantities[product.id] ?: 0) > 0) {
                                quantities[product.id] = (quantities[product.id] ?: 0) - 1
                            }
                        }
                        .size(24.dp))

                Text(
                    text = "${quantities[product.id] ?: 0}",
                    modifier = Modifier
                        .padding(horizontal = 8.dp))

                Image(painter = painterResource(id = R.drawable.plus), contentDescription = "plus",
                    modifier = Modifier
                        .clickable{
                            if ((quantities[product.id] ?: 0) > 0) {
                                quantities[product.id] = (quantities[product.id] ?: 0) + 1
                            }
                        }
                        .size(24.dp))
            }

        }
    }
}
